# -*- coding: utf-8 -*-
# @Time : 2022/2/18 17:53
# @Author : Zhan Yong
from .dataset import *
from .version import *
from .video_tool import *
# from .file_tool import *

__appname__ = "ccdt"
__version__ = "1.0.1"


from prettytable import PrettyTable

x = PrettyTable()
column_names = ["City name", "Area", "Population", "Annual Rainfall"]
x.add_column(column_names[0], ["Adelaide", "Brisbane", "Darwin", "Hobart", "Sydney", "Melbourne", "Perth"])
x.add_column(column_names[1], [1295, 5905, 112, 1357, 2058, 1566, 5386])
x.add_column(column_names[2], [1158259, 1857594, 120900, 205556, 4336374, 3806092, 1554769])
x.add_column(column_names[3], [600.5, 1146.4, 1714.7, 619.5, 1214.8, 646.9, 869.4])

print(x)


# from prettytable import PrettyTable

x = PrettyTable()

x.field_names = ["City name", "Area", "Population", "Annual Rainfall"]

x.add_row(["Adelaide", 1295, 1158259, 600.5])
x.add_row(["Brisbane", 5905, 1857594, 1146.4])
x.add_row(["Darwin", 112, 120900, 1714.7])
x.add_row(["Hobart", 1357, 205556, 619.5])
x.add_row(["Sydney", 2058, 4336374, 1214.8])
x.add_row(["Melbourne", 1566, 3806092, 646.9])
x.add_row(["Perth", 5386, 1554769, 869.4])

print(x)

raw_list = [['安全帽', '活', '工装'], ['安全帽', '活', '工装'], ['安全帽', '鞋子', '活'], ['工装', '安全帽', '活']]
new_list = [list(t) for t in set(tuple(_) for _ in raw_list)]
print(new_list)